@@ -58,9 +58,9 @@ test('Unknown CI', function (t) {
 
 test('Anonymous CI', function (t) {
   const ANONYMOUS_ENV_VARS = [
-    'CI', 'CONTINUOUS_INTEGRATION', 'BUILD_NUMBER',
-    'CI_APP_ID', 'CI_BUILD_ID', 'CI_BUILD_NUMBER',
-    'RUN_ID'
+    'CI', 'CONTINUOUS_INTEGRATION', 'BUILD_ID',
+    'BUILD_NUMBER', 'CI_APP_ID', 'CI_BUILD_ID',
+    'CI_BUILD_NUMBER', 'RUN_ID', 'CI_NAME'
   ]
 
   for (const envVar in ANONYMOUS_ENV_VARS) {
@@ -606,7 +606,7 @@ test('Netlify CI - Not PR', function (t) {
   t.end()
 })
 
-test('Vercel', function (t) {
+test('Vercel - NOW_BUILDER', function (t) {
   process.env.NOW_BUILDER = '1'
 
   clearModule('./')
@@ -623,6 +623,23 @@ test('Vercel', function (t) {
   t.end()
 })
 
+test('Vercel - VERCEL_URL', function (t) {
+  process.env.VERCEL_URL = '1'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.isPR, null)
+  t.equal(ci.name, 'Vercel')
+  t.equal(ci.VERCEL, true)
+  assertVendorConstants('VERCEL', ci, t)
+
+  delete process.env.VERCEL_URL
+
+  t.end()
+})
+
 test('Nevercode - PR', function (t) {
   process.env.NEVERCODE = 'true'
   process.env.NEVERCODE_PULL_REQUEST = 'true'
@@ -860,6 +877,22 @@ test('Xcode Server - Not PR', function (t) {
   t.end()
 })
 
+test('Heroku', function (t) {
+  const realNode = process.env.NODE
+  process.env.NODE = '/extra/content/app/.heroku/node/bin/node --extra --content'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.name, 'Heroku')
+  t.equal(ci.HEROKU, true)
+  assertVendorConstants('HEROKU', ci, t)
+
+  process.env.NODE = realNode
+  t.end()
+})
+
 function assertVendorConstants (expect, ci, t) {
   ci._vendors.forEach(function (constant) {
     let bool = constant === expect
